use std::{env::var, net::SocketAddr, path::{Path, PathBuf}};

#[derive(Debug, Clone)]
pub struct Env {
    pub listen: SocketAddr,
    pub docroot: PathBuf,
    pub tld: String
}

impl Env {
    pub fn get_doc_for_sni<T: AsRef<Path>>(&self, sni: T) -> PathBuf {
        self.docroot.clone().join(sni)
    }
}

impl Default for Env {
    fn default() -> Self {
        Self {
            listen: var("LISTEN").expect("LISTEN").parse().unwrap(),
            docroot: var("DOCROOT").expect("DOCROOT").parse().unwrap(),
            tld: var("CC_TLD").unwrap_or("cc.blek.codes".into())
        }
    }
}